# Generated by Django 5.0.9 on 2025-01-05 12:37

import django.db.models.deletion
import django.utils.timezone
from django.conf import settings
from django.db import migrations, models


def migrate_comment(apps, schema_editor):
    ParticipationComment = apps.get_model("core", "ParticipationComment")
    AbstractParticipation = apps.get_model("core", "AbstractParticipation")
    db_alias = schema_editor.connection.alias
    comments = []
    for participation in AbstractParticipation.objects.using(db_alias).all():
        if participation.comment:
            comments.append(
                ParticipationComment(participation=participation, text=participation.comment)
            )
    ParticipationComment.objects.using(db_alias).bulk_create(comments)


def revert_comments(apps, schema_editor):
    ParticipationComment = apps.get_model("core", "ParticipationComment")
    db_alias = schema_editor.connection.alias
    for comment in ParticipationComment.objects.using(db_alias).all():
        comment.participation.comment = comment.text
        comment.participation.save()


class Migration(migrations.Migration):

    dependencies = [
        ("core", "0034_alter_eventtype_show_participant_data"),
    ]

    operations = [
        migrations.CreateModel(
            name="ParticipationComment",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                (
                    "visible_for",
                    models.IntegerField(
                        choices=[
                            (0, "responsibles only"),
                            (1, "responsibles and corresponding participant"),
                            (2, "everyone"),
                        ],
                        default=0,
                        verbose_name="visible for",
                    ),
                ),
                ("text", models.CharField(max_length=255, verbose_name="Comment")),
                (
                    "authored_by_responsible",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(auto_now_add=True),
                ),
                (
                    "participation",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="comments",
                        to="core.abstractparticipation",
                    ),
                ),
            ],
        ),
        migrations.RunPython(migrate_comment, revert_comments),
        migrations.RemoveField(
            model_name="abstractparticipation",
            name="comment",
        ),
    ]
